@@ -1,4 +1,4 @@
-import cameo_table
+from cameo_table import *
 
 def main():
     n = input('選擇想要的功能 輸入1:挑選出指定欄位為某值的所有列 輸入2:將直欄轉換為橫向資料 輸入0:離開\n')
